@@ -2,10 +2,16 @@
 
 ;;; File: "_gambit#.scm"
 
-;;; Copyright (c) 1994-2014 by Marc Feeley, All Rights Reserved.
+;;; Copyright (c) 1994-2015 by Marc Feeley, All Rights Reserved.
 
 ;;;============================================================================
 
+;; Define macro-define-syntax.
+
+(##include "~~lib/_define-syntax.scm")
+
+;;;----------------------------------------------------------------------------
+
 ;; General object representation.
 
 ;; IMPORTANT: These definitions need to be consistent with the
@@ -79,45 +85,44 @@
 
 ;; System procedure classes.
 
-(##define-macro (define-prim form . exprs)
-  (let* ((name
-          (if (symbol? form)
-              form
-              (car form)))
-         (val
-          (if (symbol? form)
+(macro-define-syntax define-prim
+  (lambda (stx)
+    (syntax-case stx ()
 
-              (if (and (pair? exprs) (null? (cdr exprs)))
-                  (car exprs)
-                  (error "Incorrect define-prim"))
+      ((_ (id . params) body ...)
+       (let* ((name
+               (syntax->datum #'id))
+              (pi
+               (c#target.prim-info name))
+              (inlinable?
+               (and pi
+                    (c#proc-obj-inline pi)
+                    (let loop ((lst (syntax->datum #'params)))
+                      (if (pair? lst)
+                          (if (memq (car lst) '(#!optional #!key #!rest))
+                              #f
+                              (loop (cdr lst)))
+                          (null? lst))))))
+         (cond (inlinable?
+                #'(define-prim id
+                    (lambda params
+                      (id . params))))
+               ((not (null? (syntax->datum #'(body ...))))
+                #'(define-prim id
+                    (lambda params
+                      (##declare (inline))
+                      body ...)))
+               (else
+                (error "define-prim can't inline" name)))))
 
-              (let* ((pi
-                      (c#target.prim-info name))
-                     (inlinable?
-                      (and pi
-                           (c#proc-obj-inline pi)
-                           (let loop ((lst (cdr form)))
-                             (if (pair? lst)
-                                 (if (memq (car lst) '(#!optional #!key #!rest))
-                                     #f
-                                     (loop (cdr lst)))
-                                 (null? lst))))))
-
-                (if inlinable?
-                    `(lambda ,(cdr form)
-                       ,form)
-                    (if (null? exprs)
-                        (error "define-prim can't inline" name)
-                        `(lambda ,(cdr form)
-                           ,@exprs)))))))
-
-    `(define ,name
-       (let ()
-         (##declare
-           (not inline)
-           (standard-bindings)
-           (extended-bindings))
-         ,val))))
+      ((_ id val)
+       #'(define id
+           (let ()
+             (##declare
+               (not inline)
+               (standard-bindings)
+               (extended-bindings))
+             val))))))
 
 ;;;----------------------------------------------------------------------------
 
@@ -326,57 +331,87 @@
 
 ;;;----------------------------------------------------------------------------
 
-(##define-macro (macro-case-target . clauses)
-  (let ((target (if (and (pair? ##compilation-options)
-                         (pair? (car ##compilation-options)))
-                    (let ((t (assq 'target ##compilation-options)))
-                      (if t (cadr t) 'c))
-                    'c)))
-    (let loop ((clauses clauses))
-      (if (pair? clauses)
-          (let* ((clause (car clauses))
-                 (cases (car clause)))
-            (if (or (eq? cases 'else)
-                    (memq target cases))
-                `(begin ,@(cdr clause))
-                (loop (cdr clauses))))
-          `(begin)))))
+(macro-define-syntax macro-case-target
+  (lambda (stx)
+    (syntax-case stx (else)
+      ((_ . clauses)
+       (let ((target (if (and (pair? ##compilation-options)
+                              (pair? (car ##compilation-options)))
+                         (let ((t (assq 'target ##compilation-options)))
+                           (if t (cadr t) 'c))
+                         'c)))
+         (let loop ((clauses (syntax->list #'clauses)))
+           (if (pair? clauses)
+               (syntax-case (car clauses) (else)
+                 ((else . body)
+                  #'(begin . body))
+                 ((cases . body)
+                  (if (memq target (syntax->datum #'cases))
+                      #'(begin . body)
+                      (loop (cdr clauses)))))
+               #'(begin))))))))
 
-(##define-macro (macro-if-forces forces noforces)
-  (if ((if (and (pair? ##compilation-options)
-                (pair? (car ##compilation-options)))
-           assq
-           memq)
-       'force
-       ##compilation-options)
-      forces
-      noforces))
+(macro-define-syntax macro-if-forces
+  (lambda (stx)
+    (syntax-case stx ()
+      ((_ forces noforces)
+       (if ((if (and (pair? ##compilation-options)
+                     (pair? (car ##compilation-options)))
+                assq
+                memq)
+            'force
+            ##compilation-options)
 
-(##define-macro (macro-force-vars vars expr)
-  (if ((if (and (pair? ##compilation-options)
-                (pair? (car ##compilation-options)))
-           assq
-           memq)
-       'force
-       ##compilation-options)
-      `(let ,(map (lambda (x) `(,x (##force ,x))) vars) ,expr)
-      expr))
+           #'forces
 
-(##define-macro (macro-if-checks checks nochecks)
-  (if ((if (and (pair? ##compilation-options)
-                (pair? (car ##compilation-options)))
-           assq
-           memq)
-       'check
-       ##compilation-options)
-      checks
-      nochecks))
+           #'noforces)))))
 
-(##define-macro (macro-no-force vars expr)
-  expr)
+(macro-define-syntax macro-force-vars
+  (lambda (stx)
+    (syntax-case stx ()
+      ((_ vars expr)
+       (if ((if (and (pair? ##compilation-options)
+                     (pair? (car ##compilation-options)))
+                assq
+                memq)
+            'force
+            ##compilation-options)
 
-(##define-macro (macro-no-check var arg-num form expr)
-  expr)
+           (syntax-case (datum->syntax
+                         #'vars
+                         (map (lambda (x) `(,x (##force ,x)))
+                              (syntax->list #'vars)))
+               ()
+             (bindings #'(let bindings expr)))
+
+           #'expr)))))
+
+(macro-define-syntax macro-if-checks
+  (lambda (stx)
+    (syntax-case stx ()
+      ((_ checks nochecks)
+       (if ((if (and (pair? ##compilation-options)
+                     (pair? (car ##compilation-options)))
+                assq
+                memq)
+            'check
+            ##compilation-options)
+
+           #'checks
+
+           #'nochecks)))))
+
+(macro-define-syntax macro-no-force
+  (lambda (stx)
+    (syntax-case stx ()
+      ((_ vars expr)
+       #'expr))))
+
+(macro-define-syntax macro-no-check
+  (lambda (stx)
+    (syntax-case stx ()
+      ((_ var arg-num form expr)
+       #'expr))))
 
 (##define-macro
   (define-prim-fold bool? form zero one two forcing pre-check . post-checks)
@@ -564,10 +599,8 @@
                                       (exactly-1-arg)))))))
 
     (list 'define-prim
-          name-fn
-          (list 'lambda
-                (parameter-list)
-                (body)))))
+          (cons name-fn (parameter-list))
+          (body))))
 
 (##define-macro
   (define-prim-nary form zero one two forcing pre-check . post-checks)
