@@ -2,7 +2,7 @@
 
 ;;; File: "gambit#.scm"
 
-;;; Copyright (c) 2005-2013 by Marc Feeley, All Rights Reserved.
+;;; Copyright (c) 2005-2015 by Marc Feeley, All Rights Reserved.
 
 ;;;============================================================================
 
@@ -34,6 +34,7 @@ receive
 time
 cond-expand
 define-cond-expand-feature
+letrec*
 
 ;; global variable
 default-random-source
@@ -197,6 +198,7 @@ file-info-size
 file-info-type
 file-info?
 file-inode
+file-last-access-and-modification-times-set!
 file-last-access-time
 file-last-change-time
 file-last-modification-time
@@ -395,12 +397,11 @@ make-s8vector
 make-table
 make-thread
 make-thread-group
+make-tls-context
 make-u16vector
 make-u32vector
 make-u64vector
 make-u8vector
-make-uninterned-keyword
-make-uninterned-symbol
 make-will
 multiple-c-return-exception?
 mutex-lock!
@@ -697,6 +698,8 @@ started-thread-exception?
 step
 step-level-set!
 string->keyword
+string->uninterned-keyword
+string->uninterned-symbol
 string-ci=?-hash
 string-shrink!
 string=?-hash
